#pragma once

#include <stdint.h>

/****************************************************************************************************/

#define DDS_SAMPLE_RATE				48000		// 48kHz

#define DDS_MIN_FREQUENCY			.001f		// 1mHz
#define	DDS_MAX_FREQUENCY			20000.0f	// 20kHz

#define DDS_MAX_PHASESHIFT			359.999f	// 359.99 degrees

#define DDS_MAX_AMPLITUDE			2.56f		// 2.56Vrms (measured no load output amplitude)

#define DDS_MIN_SWEEP_TIME			.001f		// 1ms
#define DDS_MIN_BURST_TIME			.001f		// 1ms

#define DDS_TRIGGER_PULSE_LENGTH	.01f		// 10ms

/****************************************************************************************************/

enum dds_t_mode { SINE_PHASE_SHIFT, SINE_SINE, SWEEP, BURST };
enum dds_t_sweep_type { LIN, LOG };

/****************************************************************************************************/

void dds_init(void);
void dds_sample(volatile int32_t *channel1, volatile int32_t *channel2);

void dds_set_frequency(uint8_t channel, float frequency);
void dds_set_amplitude(uint8_t channel, float amplitude);
void dds_set_ch2_phaseshift(float phaseshift);
void dds_set_ch1_sweep(enum dds_t_sweep_type type, float frequency1, float frequency2, float time);
void dds_set_ch1_burst_timed(float frequency,
	float amplitude1, float t1, float amplitude2, float t2);
void dds_set_ch1_burst_cycled(float frequency,
	float amplitude1, uint32_t t1, float amplitude2, uint32_t t2);
void dds_set_mode(enum dds_t_mode mode);
void dds_set_output_enable(uint8_t channel, uint8_t output_enable);

/****************************************************************************************************/
